import React, {useState, useEffect} from 'react';
import {
  Text,
  View,
  TouchableOpacity,
  Platform,
  Linking,
  Alert,
} from 'react-native';
import styles from '../styles/Index';
import Icon from 'react-native-vector-icons/MaterialCommunityIcons';
import {textMonth} from './Index';

const Time = () => {
  //Declare state const
  const [currentTime, setCurrentTime] = useState('');
  const [currentDay, setCurrentDay] = useState('');
  const [hour, setHour] = useState('');

  //Define time icons
  const clock = <Icon name="clock" size={36} color="#5bb8b8" />;
  const calendar = <Icon name="calendar-month" size={36} color="#5bb8b8" />;

  //Get time every second and formatted the date
  useEffect(() => {
    const timeUpdate = setInterval(() => {
      setCurrentTime(
        new Date().toLocaleTimeString('es-ES', {
          hour: '2-digit',
          minute: '2-digit',
          hour12: false,
        }),
      );
    }, 1000);
    return () => {
      clearInterval(timeUpdate);
    };
  });

  //Get the current hour every second
  useEffect(() => {
    const hourUpdate = setInterval(() => {
      setHour(
        new Date().toLocaleTimeString('es-ES', {
          hour: '2-digit',
          hour12: false,
        }),
      );
    }, 1000);
    return () => {
      clearInterval(hourUpdate);
    };
  });

  //Construct the current time and date
  useEffect(() => {
    var date = new Date().getDate();
    var month = new Date().getMonth() + 1;
    var year = new Date().getFullYear();

    setCurrentDay(date + ' de ' + textMonth(month) + ' de ' + year);
  }, []);

  //Open Calendar System App
  const openCal = () => {
    Alert.alert('Atención', '¿Desea abrir la aplicación de Calendario?', [
      {
        text: 'Cancelar',
      },
      {
        text: 'OK',
        onPress: () => {
          if (Platform.OS === 'ios') {
            Linking.openURL('calshow:');
          } else if (Platform.OS === 'android') {
            Linking.openURL('content://com.android.calendar/time/');
          }
        },
      },
    ]);
  };

  //Greeting function according time frame
  const greeting = `¡Buen${
    (hour < 12 && 'os días') || (hour < 20 && 'as tardes') || 'as noches'
  } granjero!`;

  //Return component to parent view
  return (
    <>
      <View style={styles.timeText}>
        <Text style={styles.timeTextHeader}>{greeting}</Text>
      </View>
      {/* Open Platform Operating System Calendar App */}
      <TouchableOpacity
        onLongPress={() => {
          openCal();
        }}
      >
        <View style={styles.mainGroup}>
          <View style={styles.timeContainer}>
            <View style={styles.timeItem}>
              <Text style={styles.timeText}>{clock}</Text>
            </View>
            <View style={styles.timeItem}>
              <Text style={styles.timeTextCurrent}>{currentTime} </Text>
            </View>
          </View>

          <View style={styles.timeContainer}>
            <View style={styles.timeItem}>
              <Text style={styles.timeText}>{calendar}</Text>
            </View>

            <View style={styles.timeItem}>
              <Text style={styles.timeTextCurrent}> {currentDay}</Text>
            </View>
          </View>
        </View>
      </TouchableOpacity>
    </>
  );
};
export default Time;
