import React, {useState, useEffect} from 'react';
import {
  View,
  Text,
  TouchableOpacity,
  Platform,
  Linking,
  Alert,
  Image,
} from 'react-native';
import styles from '../styles/Index';
import {getWeather, showWeather} from 'react-native-weather-api';
import Geolocation from '@react-native-community/geolocation';
import Icon from 'react-native-vector-icons/MaterialCommunityIcons';

export const Weather = () => {
  //Set constants state
  const [data, setData] = useState({});
  const [currentLongitude, setCurrentLongitude] = useState('');
  const [currentLatitude, setCurrentLatitude] = useState('');

  //Assign weather icons
  const temp = <Icon name="thermometer-lines" size={36} color="#5bb8b8" />;
  const rain = <Icon name="weather-pouring" size={36} color="#5bb8b8" />;
  //const rain = <Icon name="weather-rainy" size={36} color="#5bb8b8" />;
  const wind = <Icon name="weather-windy" size={36} color="#5bb8b8" />;

  //Get current coordinates when component is enabled
  Geolocation.getCurrentPosition(
    //Will give you the current location
    position => {
      //getting the Longitude from the location json
      const longitude = JSON.stringify(position.coords.longitude);
      setCurrentLongitude(longitude);
      //getting the Latitude from the location json
      const latitude = JSON.stringify(position.coords.latitude);
      setCurrentLatitude(latitude);
    },
    // eslint-disable-next-line no-alert
    error => alert(error.message),
    {
      enableHighAccuracy: true,
      timeout: 2000000000,
      maximumAge: 1000000000,
      // timeout: 600000,
      // maximumAge: 300000,
    },
  );

  //Get weather from current position
  useEffect(() => {
    try {
      getWeather({
        key: '557367582324626d70f6a6841c394638',
        lat: currentLatitude,
        lon: currentLongitude,
        unit: 'metric',
        lang: 'es',
      }).then(() => {
        var info = new showWeather();
        setData(info);
      });
    } catch (error) {
      console.log(error);
    }
  }, [currentLongitude, currentLatitude]);

  //Open last position store in app
  const openMap = () => {
    Alert.alert(
      'Atención',
      '¿Desea ver su ubicación en la aplicación del sistema',
      [
        {
          text: 'Cancelar',
        },
        {
          text: 'OK',
          onPress: () => {
            if (Platform.OS === 'ios') {
              Linking.openURL(
                'maps:' + currentLatitude + ',' + currentLongitude,
              );
            } else if (Platform.OS === 'android') {
              Linking.openURL(
                'geo:' + currentLatitude + ',' + currentLongitude,
              );
            }
          },
        },
      ],
    );
  };

  //Return the structured component to main view (farm=home view)
  return (
    <TouchableOpacity
      onLongPress={() => {
        openMap();
      }}
    >
      <View style={styles.mainGroup}>
        <View style={styles.weatherContainer}>
          <View style={styles.weatherItem}>
            <Image
              style={styles.weatherIconApi}
              source={{
                uri: `${data.icon}`,
              }}
            />
          </View>
          <View style={styles.weatherItemText}>
            <Text style={styles.weatherTextCap}>{data.description}</Text>
          </View>
        </View>
        <View style={styles.weatherContainer}>
          <View style={styles.weatherGroup}>
            <View style={styles.weatherItem}>
              <Text style={styles.weatherText}>{temp} </Text>
            </View>
            <View style={styles.weatherItemText}>
              <Text style={styles.weatherText}>{data.temp} °C</Text>
            </View>
          </View>
          <View style={styles.weatherGroup}>
            <View style={styles.weatherItem}>
              <Text style={styles.weatherText}>{rain}</Text>
            </View>
            <View style={styles.weatherItemText}>
              <Text style={styles.weatherText}>{data.humidity} %</Text>
            </View>
          </View>
          <View style={styles.weatherGroup}>
            <View style={styles.weatherItem}>
              <Text style={styles.weatherText}>{wind}</Text>
            </View>
            <View style={styles.weatherItemText}>
              <Text style={styles.weatherText}>{data.wind} km/h</Text>
            </View>
          </View>
        </View>
      </View>
    </TouchableOpacity>
  );
};
export default Weather;
