/* eslint-disable react-native/no-inline-styles */
import React from 'react';
import {Text, View} from 'react-native';
import {createBottomTabNavigator} from '@react-navigation/bottom-tabs';
import {LiveStock} from '../views/LiveStock';
import {Crops} from '../views/Crops';
import {Farm} from '../views/Farm';
import {Settings} from '../views/Settings';
import styles from '../styles/Index';
import Icon from 'react-native-vector-icons/MaterialCommunityIcons';

//Define the icons used in menu bar
const animales = <Icon name="cow" size={36} />;
const cultivos = <Icon name="grass" size={36} />;
const ajustes = <Icon name="tractor-variant" size={36} />;
const granja = <Icon name="barn" size={36} />;

//Declare the menu bar from function call
const BarTab = createBottomTabNavigator();

//Construct the navigation component view
export const TabNavigator = () => {
  return (
    //Create the navigation menu bar
    <BarTab.Navigator
      initialRouteName="Granja"
      screenOptions={{
        headerBackVisible: true,
        headerShadowVisible: true,
        tabBarActiveBackgroundColor: '#009192',
        tabBarInactiveBackgroundColor: '#009192',
        tabBarShowLabel: false,
        tabBarInactiveTintColor: 'white',
        tabBarActiveTintColor: '#7fc8c8',
        headerStyle: {
          backgroundColor: '#009192',
        },
        headerTitleStyle: {
          color: 'white',
        },
        tabBarStyle: {
          flex: 1,
          flexDirection: 'row',
          justifyContent: 'space-between',
          position: 'absolute',
          left: 0,
          right: 0,
          bottom: 0,
          backgroundColor: '#009192',
          minHeight: 75,
        },
      }}
    >
      {/* Define each menu item */}
      <BarTab.Screen
        name="Granja"
        options={{
          title: 'Mi Granja',
          headerTitleAlign: 'center',
          tabBarIcon: props => (
            <View style={styles.menuItem}>
              <Text style={{color: props.color}}>{granja}</Text>
              <Text style={{color: props.color, fontWeight: '700'}}>
                Inicio
              </Text>
            </View>
          ),
        }}
        component={Farm}
      />

      <BarTab.Screen
        name="Ganado"
        options={{
          title: 'Mi Ganado',
          headerTitleAlign: 'center',
          tabBarIcon: props => (
            <View style={styles.menuItem}>
              <Text style={{color: props.color}}>{animales}</Text>
              <Text style={{color: props.color, fontWeight: '700'}}>
                Ganado
              </Text>
            </View>
          ),
        }}
        component={LiveStock}
      />
      <BarTab.Screen
        name="Cultivos"
        options={{
          title: 'Mis Cultivos',
          headerTitleAlign: 'center',
          tabBarIcon: props => (
            <View style={styles.menuItem}>
              <Text style={{color: props.color}}>{cultivos}</Text>
              <Text style={{color: props.color, fontWeight: '700'}}>
                Cultivos
              </Text>
            </View>
          ),
        }}
        component={Crops}
      />
      <BarTab.Screen
        name="Inicio"
        options={{
          title: 'Mis Ajustes',
          headerTitleAlign: 'center',
          tabBarIcon: props => (
            <View style={styles.menuItem}>
              <Text style={{color: props.color}}>{ajustes}</Text>
              <Text style={{color: props.color, fontWeight: '700'}}>
                Ajustes
              </Text>
            </View>
          ),
        }}
        component={Settings}
      />
    </BarTab.Navigator>
  );
};
