//Crops main view
import React, {useState, useEffect} from 'react';
import {
  ImageBackground,
  View,
  Text,
  Alert,
  TouchableOpacity,
} from 'react-native';
import styles from '../styles/Index';
import Crop from '../components/Crop';
import CropForm from '../components/CropForm';
import {FlatList} from 'react-native-gesture-handler';
import AsyncStorage from '@react-native-async-storage/async-storage';

export const Crops = () => {
  //State const
  const [cropModal, setCropModal] = useState(false);
  const [cultures, setCultures] = useState([]);
  const [culture, setCulture] = useState({});

  useEffect(() => {
    //Get storage data
    const getCultureStorage = async () => {
      try {
        const cultureStorage = await AsyncStorage.getItem('cultures');
        if (cultureStorage) {
          setCultures(JSON.parse(cultureStorage));
        }
      } catch (error) {
        console.log(error);
      }
    };
    getCultureStorage();
  }, []);

  //Edit a crop by id
  const cropEdit = id => {
    const edit = cultures.filter(item => item.id === id);
    setCulture(edit[0]);
  };

  //Remove a crop by id
  const cropDel = id => {
    Alert.alert(
      '¿Desea eliminar éste cultivo?',
      'Un cultivo eliminado no se puede recuperar',
      [
        {text: 'Cancelar'},
        {
          text: 'Eliminar',
          onPress: () => {
            const cropsUpdate = cultures.filter(
              culturesState => culturesState.id !== id,
            );
            setCultures(cropsUpdate);
            saveCultureStorage(JSON.stringify(cropsUpdate));
          },
        },
      ],
    );
  };

  //Save Crops in storage
  const saveCultureStorage = async cultureJSON => {
    try {
      await AsyncStorage.setItem('cultures', cultureJSON);
    } catch (error) {
      console.log(error);
    }
  };

  return (
    <View style={styles.tab}>
      <ImageBackground
        source={require('../img/cropsbg.jpg')}
        resizeMode="cover"
        style={styles.backgroundImage}
      >
        {/* Add new crop button */}
        <TouchableOpacity
          onPress={() => setCropModal(!cropModal)}
          style={styles.btnAdd}
        >
          <Text style={styles.btnAddText}>Añadir Cultivo</Text>
        </TouchableOpacity>

        {/* Check condition if already exists cultures */}
        {cultures.length === 0 ? (
          <Text style={styles.tabText}>¡No hay cultivos en proceso!</Text>
        ) : (
          //List og cultures
          <FlatList
            style={styles.flatList}
            data={cultures}
            keyExtractor={item => item.id}
            renderItem={({item}) => {
              return (
                //Define a item list structure
                <Crop
                  item={item}
                  setCropModal={setCropModal}
                  cropEdit={cropEdit}
                  cropDel={cropDel}
                />
              );
            }}
          />
        )}
        {/* CRUD operations form */}
        <CropForm
          cropModal={cropModal}
          setCropModal={setCropModal}
          cultures={cultures}
          setCultures={setCultures}
          culture={culture}
          setCulture={setCulture}
          saveCultureStorage={saveCultureStorage}
        />
      </ImageBackground>
    </View>
  );
};
