//LiveStock view
import React, {useState, useEffect} from 'react';
import {
  ImageBackground,
  View,
  Text,
  Alert,
  TouchableOpacity,
} from 'react-native';
import styles from '../styles/Index';
import {FlatList} from 'react-native-gesture-handler';
import Stock from '../components/Stock';
import StockForm from '../components/StockForm';
import AsyncStorage from '@react-native-async-storage/async-storage';

//State const
export const LiveStock = () => {
  const [livestockModal, setLivestockModal] = useState(false);
  const [livestock, setLivestock] = useState([]);
  const [animal, setAnimal] = useState({});

  useEffect(() => {
    //Getting, at start, storage data
    const getLivestockStorage = async () => {
      try {
        const livestockStorage = await AsyncStorage.getItem('livestock');
        if (livestockStorage) {
          setLivestock(JSON.parse(livestockStorage));
        }
      } catch (error) {
        console.log(error);
      }
    };
    getLivestockStorage();
  }, []);

  //Edit one animal properties through id
  const livestockEdit = id => {
    const edit = livestock.filter(item => item.id === id);
    setAnimal(edit[0]);
  };

  //Remove one animal from the array
  const livestockDel = id => {
    Alert.alert(
      '¿Desea eliminar éste animal?',
      'Un animal eliminado no se puede recuperar',
      [
        {text: 'Cancelar'},
        {
          text: 'Eliminar',
          onPress: () => {
            const livestockUpdate = livestock.filter(
              stockState => stockState.id !== id,
            );
            setLivestock(livestockUpdate);
            saveLivestockStorage(JSON.stringify(livestockUpdate));
          },
        },
      ],
    );
  };

  //Save state livestock in persistence storage
  const saveLivestockStorage = async stockJSON => {
    try {
      await AsyncStorage.setItem('livestock', stockJSON);
    } catch (error) {
      console.log(error);
    }
  };
  return (
    <View style={styles.tab}>
      <ImageBackground
        source={require('../img/livestockbg.jpg')}
        resizeMode="cover"
        style={styles.backgroundImage}
      >
        {/* Add new animal button */}
        <TouchableOpacity
          onPress={() => setLivestockModal(!livestockModal)}
          style={styles.btnAdd}
        >
          <Text style={styles.btnAddText}>Añadir Animal</Text>
        </TouchableOpacity>
        {/* Check if exists any animal */}
        {livestock.length === 0 ? (
          <Text style={styles.tabText}>¡Todavía no tiene ningún animal!</Text>
        ) : (
          //Show listed storage livestock
          <FlatList
            style={styles.flatList}
            data={livestock}
            keyExtractor={item => item.id}
            renderItem={({item}) => {
              return (
                //Define properties shows from listed stock
                <Stock
                  item={item}
                  setLivestockModal={setLivestockModal}
                  livestockEdit={livestockEdit}
                  livestockDel={livestockDel}
                />
              );
            }}
          />
        )}
        {/* Passing props to Form CRUD component */}
        <StockForm
          livestockModal={livestockModal}
          setLivestockModal={setLivestockModal}
          livestock={livestock}
          setLivestock={setLivestock}
          animal={animal}
          setAnimal={setAnimal}
          saveLivestockStorage={saveLivestockStorage}
        />
      </ImageBackground>
    </View>
  );
};
